@@ -22,9 +22,9 @@
 #include "invitationsrfbclient.h"
 #include "krfbconfig.h"
 #include "rfbservermanager.h"
-#include <QtCore/QTimer>
+#include <QTimer>
 #include <QApplication>
-#include <QtNetwork/QHostInfo>
+#include <QHostInfo>
 #include <QDebug>
 
 #include <KLocalizedString>
@@ -115,8 +115,8 @@ void InvitationsRfbServer::toggleUnattendedAccess(bool allow)
 
 InvitationsRfbServer::InvitationsRfbServer()
 {
-    m_desktopPassword = readableRandomString(4)+"-"+readableRandomString(3);
-    m_unattendedPassword = readableRandomString(4)+"-"+readableRandomString(3);
+    m_desktopPassword = readableRandomString(4)+'-'+readableRandomString(3);
+    m_unattendedPassword = readableRandomString(4)+'-'+readableRandomString(3);
     KConfigGroup krfbConfig(KSharedConfig::openConfig(),"Security");
     m_allowUnattendedAccess = krfbConfig.readEntry(
             "allowUnattendedAccess", QVariant(false)).toBool();
@@ -223,5 +223,3 @@ QString InvitationsRfbServer::readableRandomString(int length)
     }
     return str;
 }
-
-#include "invitationsrfbserver.moc"
